#!/bin/bash
 
# Modified digital camera thumbnail/contact sheet tool.
# Original by John Hobbs
# http://www.velvetcache.org/2009/03/30/imagemagick-thumbnails-and-contact-sheets
# http://github.com/jmhobbs/helper-scripts
#
# This version modified by zenpho 2014
#
# Permission is hereby granted, free of charge, to any person
# obtaining a copy of this software and associated documentation
# files (the "Software"), to deal in the Software without
# restriction, including without limitation the rights to use,
# copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following
# conditions:
#
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
# OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
# HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
# OTHER DEALINGS IN THE SOFTWARE.
 
# CHANGELOG
# 2014-03-04 - Modified to run from a "main project" directory
# 2010-06-14 - Fixed contact sheet problem, thanks to Glenn Turnbull. (John Hobbs)
# 2009-03-30 - Created script. (John Hobbs)
 
### SETTINGS ### 
# Working directory
# - here we will find the frames to process
# - here we will make a $CONTACTDIR
WORKINGDIR="./frames"
# Contact Item Size
CONTACTSIZE="320x240"
# Contact Sheet Max Width
CONTACTWIDTH="10"
# Contact Sheet Max Height
CONTACTHEIGHT="14"
# Horizontal Spacing
CONTACTSPACINGH="0"
# Vertical Spacing
CONTACTSPACINGV="0"
# Contact Sheet Directory
CONTACTDIR="contact"
# Contact Sheet Quality
CONTACTQUALITY="100"
 
################

cd $WORKINGDIR 
CONTACTCOUNT=$(($CONTACTWIDTH * $CONTACTHEIGHT))
PIX=$(ls -l *.png | wc -l)

echo
echo "Creating Contact Sheets from $PIX Images"
 
mkdir -p $CONTACTDIR
CTR=0
PAGES=$(($PIX / $CONTACTCOUNT))
if [ $(($PIX % $CONTACTCOUNT)) -ne 0 ]; then
    PAGES=$(($PAGES + 1))
fi
 
PAGE=1
LIST=""
for i in *.png; do
    if [ $(($CTR % $CONTACTCOUNT)) -eq 0 ] && [ $CTR -ne 0 ]; then
        echo "$PAGE of $PAGES"
        montage -border 5 -tile ${CONTACTWIDTH}x${CONTACTHEIGHT} -geometry ${CONTACTSIZE}+${CONTACTSPACINGH}+${CONTACTSPACINGV}\! $LIST png:- > ${CONTACTDIR}/${PAGE}.png
        LIST=""
        PAGE=$(($PAGE + 1))
    fi
    LIST="$LIST $i"
    CTR=$(($CTR + 1))
done
 
if [ "" != "$LIST" ]; then
    echo "$PAGE of $PAGES"
    montage -border 5 -tile ${CONTACTWIDTH}x${CONTACTHEIGHT} -geometry ${CONTACTSIZE}+${CONTACTSPACINGH}+${CONTACTSPACINGV}\! $LIST png:- > ${CONTACTDIR}/${PAGE}.png
fi

echo 
echo Moving $CONTACTDIR to main directory
rm -r ../$CONTACTDIR
rmdir ../$CONTACTDIR
mv $CONTACTDIR ../

echo "Done creating contact sheets"
cd ..
